// java wrapper for vtkOutEdgeIterator object
//

package vtk;
import vtk.*;

public class vtkOutEdgeIterator extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(vtkGraph id0,int id1);
  public void Initialize(vtkGraph id0,int id1)
    { Initialize_2(id0,id1); }

  private native long GetGraph_3();
  public vtkGraph GetGraph() {
    long temp = GetGraph_3();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetVertex_4();
  public int GetVertex()
    { return GetVertex_4(); }

  private native long NextGraphEdge_5();
  public vtkGraphEdge NextGraphEdge() {
    long temp = NextGraphEdge_5();

    if (temp == 0) return null;
    return (vtkGraphEdge)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean HasNext_6();
  public boolean HasNext()
    { return HasNext_6(); }

  public vtkOutEdgeIterator() { super(); }

  public vtkOutEdgeIterator(long id) { super(id); }
  public native long   VTKInit();

}
